Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(232)

Unified Diff: ui/gfx/canvas.h

Issue 2764633002: cc/paint: Remove cc::PaintSurface. (Closed)
Patch Set: more stuff Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/gfx/canvas.h
diff --git a/ui/gfx/canvas.h b/ui/gfx/canvas.h
index 4fcb4bcfbdfe563610198d12239de0f6e12ec6e4..1be056ac36ca0b85c771030b0fbb67d3607d3e90 100644
--- a/ui/gfx/canvas.h
+++ b/ui/gfx/canvas.h
@@ -14,7 +14,6 @@
#include "base/strings/string16.h"
#include "cc/paint/paint_canvas.h"
#include "cc/paint/paint_flags.h"
-#include "cc/paint/paint_surface.h"
#include "ui/gfx/image/image_skia.h"
#include "ui/gfx/native_widget_types.h"
#include "ui/gfx/text_constants.h"
@@ -503,10 +502,10 @@ class GFX_EXPORT Canvas {
float image_scale_;
// canvas_ is our active canvas object. Sometimes we are also the owner,
// in which case surface_ will be set. Other times we are just
// borrowing someone else's canvas, in which case canvas_ will point there
- // but surface_ will be null.
- sk_sp<cc::PaintSurface> surface_;
+ // but owned_canvas_ will be null.
+ std::unique_ptr<cc::PaintCanvas> owned_canvas_;
cc::PaintCanvas* canvas_;
DISALLOW_COPY_AND_ASSIGN(Canvas);
@@ -503,10 +502,10 @@ class GFX_EXPORT Canvas {
float image_scale_;
// canvas_ is our active canvas object. Sometimes we are also the owner,
- // in which case surface_ will be set. Other times we are just
+ // in which case owned_canvas_ will be set. Other times we are just
// borrowing someone else's canvas, in which case canvas_ will point there

Powered by Google App Engine
This is Rietveld 408576698